API_KEY = "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"
DEFAULT_MODEL = "gpt-5-chat"
OPENROUTER_URL = "https://openrouter.ai/api/v1/chat/completions"

# Если хочешь — задай атрибуцию (не обязательно)
HTTP_REFERER = None   # например "https://yourapp.example"
X_TITLE      = None   # например "bbm_q"
